#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-GFL6IugsglpIqMJrjAfLiu
key:                  hls-test-utils-2.3.0.0-GFL6IugsglpIqMJrjAfLiu
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d4e3fd46a9ad87b703a922702e093de7
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-GFL6IugsglpIqMJrjAfLiu
depends:
    aeson-2.2.1.0-A71cfLUaGyLArzjDm23YCT
    async-2.2.6-IXER6sJdc7YHGmcgizEodd base-4.18.2.1
    blaze-markup-0.8.3.0-DiaEcmdFIWULBQgZYUzUEx bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 extra-1.7.16-2PWm640KjWzJS4LkjIyaan
    filepath-1.4.300.1 ghcide-2.3.0.0-Hlz9iyA0QZeAnSORZKavOy
    hls-graph-2.3.0.0-49SURZyYUZU60vKjBpDemp
    hls-plugin-api-2.3.0.0-88NH5yynXbj514QpGYzYb8
    lens-5.3.4-LseuwroR7pl6sDSKi6iO2O
    lsp-2.2.0.0-HVGkLd1F33cFThbkDgpmo4
    lsp-test-0.16.0.0-53ZW8hRTPNr5J2DtRV8ER1
    lsp-types-2.0.2.0-LZLjivmfqf3IpYkVmbOWIA
    row-types-1.0.1.2-Ebtgs7HLDic4TwAglN4ZAx
    tasty-1.5.2-FhQxW1F8kTZC70FeLaA0bQ
    tasty-expected-failure-0.12.3-I8AFzmJMRJTJ88KcTrLBsD
    tasty-golden-2.3.5-LAGorfcDD79DT8MmdAa1L4
    tasty-hunit-0.10.2-DhLzMlVyrqV57OIMd3nsa2
    tasty-rerun-1.1.20-1l5G4cm9ail36CXEdhKdDr
    temporary-1.3-BugtgBxw3NR7rQmKFO3qXs text-2.0.2
    unordered-containers-0.2.20.1-2gLa11KPU9tAOCQUon3yBM

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

